"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var sym = require("./symbols");
var common_1 = require("./common");
var ValidationOptions;
(function (ValidationOptions) {
    ValidationOptions[ValidationOptions["any"] = 0] = "any";
    ValidationOptions[ValidationOptions["all"] = 1] = "all";
})(ValidationOptions = exports.ValidationOptions || (exports.ValidationOptions = {}));
function Primitive(ctor, name) {
    if (name === void 0) { name = Primitive.name; }
    return Type(ctor, name);
}
exports.Primitive = Primitive;
function Type(ctor, name) {
    if (name === void 0) { name = Type.name; }
    if (common_1.isNullOrUndefined(ctor) || common_1.isNullOrUndefined(ctor.prototype))
        throw new Error('Schema error, not a valid type.');
    var result = (function () { });
    result[sym.Validator] = sym.TypeValidator;
    result[sym.TypeValidator] = ctor.prototype.constructor.name;
    result[sym.Metadata] = { name: name };
    return result;
}
exports.Type = Type;
function Options(schemas, name, option) {
    if (name === void 0) { name = Options.name; }
    if (option === void 0) { option = ValidationOptions.any; }
    var result = (function () { });
    result[sym.Validator] = sym.OptionsValidator;
    result[sym.OptionsValidator] = { schemas: schemas, option: option };
    result[sym.Metadata] = { name: name };
    return result;
}
exports.Options = Options;
function Any(schemas, name) {
    if (name === void 0) { name = Any.name; }
    return Options(schemas, name, ValidationOptions.any);
}
exports.Any = Any;
function All(schemas, name) {
    if (name === void 0) { name = All.name; }
    return Options(schemas, name, ValidationOptions.all);
}
exports.All = All;
function Optional(schema, name) {
    if (name === void 0) { name = Optional.name; }
    return Options([schema, undefined], name);
}
exports.Optional = Optional;
function Nullable(schema, name) {
    if (name === void 0) { name = Nullable.name; }
    return Options([schema, null], name);
}
exports.Nullable = Nullable;
function Validator(method, name) {
    if (name === void 0) { name = Validator.name; }
    var result = (function () { });
    result[sym.Validator] = sym.CustomValidator;
    result[sym.CustomValidator] = method;
    result[sym.Metadata] = { name: name };
    return result;
}
exports.Validator = Validator;
function Alias(validator, name) {
    if (name === void 0) { name = Alias.name; }
    validator[sym.Metadata].name = name;
    return validator;
}
exports.Alias = Alias;
//# sourceMappingURL=validators.js.map